# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-11-27 22:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0033_relatedbill"),
    ]

    operations = [
        migrations.AddField(
            model_name="event",
            name="guid",
            field=models.CharField(
                default=None, max_length=255, null=True, unique=True
            ),
        ),
    ]
