# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-10-17 21:40
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0024_auto_20161017_1201"),
    ]

    operations = [
        migrations.AlterField(
            model_name="eventagendaitem",
            name="bill",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="related_agenda_items",
                to="councilmatic_core.Bill",
            ),
        ),
    ]
